ShareResult class

Constructors

ShareResult(bool success, Uri uri, {String? target})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
Whether the sharing was successful, i.e. the uri was send to a user-selected sharing application.
final
target → String?
The target of the sharing, i.e. the application that the user selected to share the uri with.
final
uri → Uri
The uri that was shared, including any UTM tracking parameters that were added.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited