ShareLink class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
shareUri(Uri uri, {String? subject, Rect? shareOrigin})
→ Future<ShareResult>
-
Shares a
uri via the platform-specific interface. When possible, UTM
tracking parameters are added to the uri.